download: Telecharger un dataset du recensement / Download a census...

View source: R/download.R

downloadR Documentation

Telecharger un dataset du recensement / Download a census dataset

Description

Telecharger un dataset du recensement / Download a census dataset

Usage

download(dataset_id, force = FALSE)

Arguments

dataset_id

L'identifiant du dataset (ex: 2013, "projection") / Dataset identifier (e.g., 2013, "projection")

force

Telecharger meme si le fichier est deja en cache / Logical, whether to force download even if cached

Value

A character string specifying the local file path to the downloaded/cached file (returned invisibly).

Examples


download("projection")


sencensus documentation built on Sept. 26, 2026, 5:06 p.m.