| download | R Documentation |
Telecharger un dataset du recensement / Download a census dataset
download(dataset_id, force = FALSE)
dataset_id |
L'identifiant du dataset (ex: 2013, "projection") / Dataset identifier (e.g., 2013, "projection") |
force |
Telecharger meme si le fichier est deja en cache / Logical, whether to force download even if cached |
A character string specifying the local file path to the downloaded/cached file (returned invisibly).
download("projection")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.